Changelog
=========

0.9.0
-----
* restructure module
* add citation
* add conda support
* add github test action
* add github pypi action
* add github citation action
* add copyright stuff
* add ruff support
* overall linting of files
* use build.os for .readthedocs
* add more badges, tweak colors

v0.5.1
------
* create pure python packaging
* include wheel file
* package as python3 only
* fix flake8 warnings
* add pypi badge
* add new targets
* automate notebook checking

v0.5.0
------
* initial check-in
* basic functionality for Ronchi tests
* basic functionality for Foucault knife edge tests
